==> pointblank_0.4.0.tar.gz: pointblank/R/utils_text_table_scan.R <==
#
# Text for table scan (ts) report
#

nav_title_ts <- 
  c(
    "en" = "Table Scan",
    "fr" = "Scan de table",
    "de" = "Tabellenscan",
    "it" = "Scansione della tabella",
    "es" = "Escaneo de Tabla"
  )

nav_overview_ts <- 
  c(
    "en" = "Overview",
    "fr" = "Aper\u00E7u",
    "de" = "\u00DCberblick",
    "it" = "Panoramica",
    "es" = "Resumen"
  )

nav_variables_ts <- 
  c(
    "en" = "Variables",
    "fr" = "Variables",
    "de" = "Variablen",
    "it" = "Variabili",
    "es" = "Variables"
  )

nav_interactions_ts <- 
  c(
    "en" = "Interactions",
    "fr" = "Interactions",
    "de" = "Interaktionen",
    "it" = "Interazioni",
    "es" = "Interacciones"
  )

nav_correlations_ts <- 
  c(
    "en" = "Correlations",
    "fr" = "Corr\u00E9lations",
    "de" = "Korrelationen",
    "it" = "Correlazioni",
    "es" = "Correlaciones"
  )

nav_missing_values_ts <- 
  c(
    "en" = "Missing Values",
    "fr" = "Valeurs manquantes",
    "de" = "Fehlende Werte",
    "it" = "Valori mancanti",
    "es" = "Valores faltantes"
  )

nav_sample_values_ts <- 
  c(
    "en" = "Sample",
    "fr" = "Exemple",
    "de" = "Stichprobe",
    "it" = "Campione",
    "es" = "Muestra"
  )

section_title_overview_of_ts <- 
  c(
    "en" = "Overview of <code>{tbl_name}</code>",
    "fr" = "Aper\u00E7u du tableau <code>{tbl_name}</code>",
    "de" = "\u00DCbersicht der Tabelle <code>{tbl_name}</code>",
    "it" = "Panoramica della tabella <code>{tbl_name}</code>",
    "es" = "Resumen de la tabla <code>{tbl_name}</code>"
  )

section_title_overview_ts <- nav_overview_ts
section_title_variables_ts <- nav_variables_ts
section_title_interactions_ts <- nav_interactions_ts
section_title_correlations_ts <- nav_correlations_ts
section_title_missing_values_ts <- nav_missing_values_ts
section_title_sample_values_ts <- nav_sample_values_ts


button_label_overview_overview_ts <- nav_overview_ts

button_label_overview_reproducibility_ts <-
  c(
    "en" = "Reproducibility",
    "fr" = "Reproductibilit\u00E9",
    "de" = "Reproduzierbarkeit",
    "it" = "Riproducibilit\u00E0",
    "es" = "Reproducibilidad"
  )

tab_label_variables_statistics_ts <-
  c(
    "en" = "Statistics",
    "fr" = "Statistiques",
    "de" = "Statistiken",
    "it" = "Statistica",
    "es" = "Estad\u00EDsticas"
  )

tab_label_variables_common_values_ts <-
  c(
    "en" = "Common Values",
    "fr" = "Valeurs communes",
    "de" = "Gemeinsame Werte",
    "it" = "Valori comuni",
    "es" = "Valores comunes"
  )

tab_label_variables_max_min_slices_ts <-
  c(
    "en" = "Max/Min Slices",
    "fr" = "Tranche sup\u00E9rieure et inf\u00E9rieure",
    "de" = "Obere und untere Scheibe",
    "it" = "Fetta superiore e inferiore",
    "es" = "Rebanada superior e inferior"
  )

subsection_title_overview_table_overview <-
  c(
    "en" = "Table Overview",
    "fr" = "Aper\u00E7u du tableau",
    "de" = "\u00DCbersicht der Tabelle",
    "it" = "Panoramica della tabella",
    "es" = "Resumen de la tabla"
  )

subsection_title_overview_column_types <-
  c(
    "en" = "Column Types",
    "fr" = "Types de colonnes",
    "de" = "Spaltentypen",
    "it" = "Tipi di colonna",
    "es" = "Tipos de columna"
  )

subsection_title_overview_reproducibility_information <-
  c(
    "en" = "Reproducibility Information",
    "fr" = "Informations sur la reproductibilit\u00E9",
    "de" = "Informationen zur Reproduzierbarkeit",
    "it" = "Informazioni sulla riproducibilit\u00E0",
    "es" = "Informaci\u00F3n de reproducibilidad"
  )

subsection_title_variables_quantile_statistics <-
  c(
    "en" = "Quantile Statistics",
    "fr" = "Statistiques quantiles",
    "de" = "Quantile Statistik",
    "it" = "Statistiche quantili",
    "es" = "Estad\u00EDsticas cuantiles"
  )

subsection_title_variables_descriptive_statistics <-
  c(
    "en" = "Descriptive Statistics",
    "fr" = "Statistiques descriptives",
    "de" = "Beschreibende Statistik",
    "it" = "Statistiche descrittive",
    "es" = "Estad\u00EDsticas descriptivas"
  )

subsection_title_variables_common_values <- tab_label_variables_common_values_ts

subsection_title_variables_maximum_values <-
  c(
    "en" = "Maximum Values",
    "fr" = "Valeurs maximales",
    "de" = "Maximalwerte",
    "it" = "Valori massimi",
    "es" = "Valores m\u00E1ximos"
  )

subsection_title_variables_minimum_values <-
  c(
    "en" = "Minimum Values",
    "fr" = "Valeurs minimales",
    "de" = "Mindestwerte",
    "it" = "Valori minimi",
    "es" = "Valores m\u00EDnimos"
  )

subsection_title_variables_string_lengths <-
  c(
    "en" = "String Lengths",
    "fr" = "Longueurs de cha\u00EEne de caract\u00E8res",
    "de" = "String-L\u00E4ngen",
    "it" = "Lunghezza delle stringhe",
    "es" = "Longitudes de la cadena de caracteres"
  )

subsection_title_variables_histogram <-
  c(
    "en" = "Histogram",
    "fr" = "Histogramme",
    "de" = "Histogramm",
    "it" = "Istogramma",
    "es" = "Histograma"
  )

btn_toggle_details <- 
  c(
    "en" = "Toggle details",
    "fr" = "Basculer les d\u00E9tails",
    "de" = "Details umschalten",
    "it" = "Attiva / disattiva i dettagli",
    "es" = "Alternar detalles"
  )

tbl_lab_columns <- 
  c(
    "en" = "Columns",
    "fr" = "Colonnes",
    "de" = "Spalten",
    "it" = "Colonne",
    "es" = "Columnas"
  )

tbl_lab_rows <- 
  c(
    "en" = "Rows",
    "fr" = "Enregistrements",
    "de" = "Datens\u00E4tzen",
    "it" = "Record",
    "es" = "Registros"
  )

tbl_lab_NAs <- 
  c(
    "en" = "`NA`s",
    "fr" = "Valeurs `NA`",
    "de" = "`NA`-Werte",
    "it" = "Valori `NA`",
    "es" = "Valores de `NA`"
  )

tbl_lab_duplicate_rows <- 
  c(
    "en" = "Duplicate Rows",
    "fr" = "Enregistrements en double",
    "de" = "Doppelte Datens\u00E4tzen",
    "it" = "Record duplicati",
    "es" = "Registros duplicados"
  )

tbl_lab_scan_build_time <- 
  c(
    "en" = "Scan Build Time",
    "fr" = "Moment de l'analyse",
    "de" = "Zeitpunkt des Scans",
    "it" = "Tempo di scansione",
    "es" = "Tiempo de escaneo"
  )

tbl_lab_pointblank_version <- 
  c(
    "en" = "**pointblank** Version",
    "fr" = "version **pointblank**",
    "de" = "**pointblank** Version",
    "it" = "versione **pointblank**",
    "es" = "Versi\u00F3n **pointblank**"
  )

tbl_lab_r_version <- 
  c(
    "en" = "**R** Version",
    "fr" = "version **R**",
    "de" = "**R** Version",
    "it" = "versione **R**",
    "es" = "Versi\u00F3n **R**"
  )

tbl_lab_system_os <- 
  c(
    "en" = "Operating System",
    "fr" = "Syst\u00E8me op\u00E9rateur",
    "de" = "Betriebssystem",
    "it" = "Sistema operativo",
    "es" = "Sistema operativo"
  )

tbl_lab_distinct <- 
  c(
    "en" = "Distinct",
    "fr" = "valeurs uniques",
    "de" = "Eindeutigen Werten",
    "it" = "Valori unici",
    "es" = "Valores \u00FAnicos"
  )

tbl_lab_mean <- 
  c(
    "en" = "Mean",
    "fr" = "Moyenne",
    "de" = "MW",
    "it" = "Media",
    "es" = "Media"
  )

tbl_lab_minimum <- 
  c(
    "en" = "Minimum",
    "fr" = "Minimum",
    "de" = "Minimum",
    "it" = "Minimo",
    "es" = "M\u00EDnimo"
  )

tbl_lab_maximum <- 
  c(
    "en" = "Maximum",
    "fr" = "Maximum",
    "de" = "Maximum",
    "it" = "Massimo",
    "es" = "M\u00E1ximo"
  )

tbl_lab_5_percentile <- 
  c(
    "en" = "5th Percentile",
    "fr" = "5e centile",
    "de" = "5 Perzentil",
    "it" = "5 percentile",
    "es" = "Quinto percentil"
  )

tbl_lab_median <- 
  c(
    "en" = "Median",
    "fr" = "M\u00E9diane",
    "de" = "Median",
    "it" = "Mediana",
    "es" = "Mediana"
  )

tbl_lab_95_percentile <- 
  c(
    "en" = "95th Percentile",
    "fr" = "95e centile",
    "de" = "95 Perzentil",
    "it" = "95 percentile",
    "es" = "Percentil 95"
  )

tbl_lab_range <- 
  c(
    "en" = "Range",
    "fr" = "\u00C9tendue",
    "de" = "Spannweite",
    "it" = "Campo di variazione",
    "es" = "Rango"
  )

tbl_lab_variance <- 
  c(
    "en" = "Variance",
    "fr" = "Variance",
    "de" = "Varianz ",
    "it" = "Varianza",
    "es" = "Varianza"
  )

tbl_lab_standard_deviation <- 
  c(
    "en" = "Standard Deviation",
    "fr" = "\u00C9cart type",
    "de" = "Standardabweichung",
    "it" = "Deviazione standard",
    "es" = "Desviaci\u00F3n Est\u00E1ndar"
  )

tbl_lab_cov <- 
  c(
    "en" = "Coefficient of Variation",
    "fr" = "Coefficient de variation",
    "de" = "Variationskoeffizient",
    "it" = "Coefficiente di variazione",
    "es" = "Coeficiente de variaci\u00F3n"
  )

tbl_lab_value <- 
  c(
    "en" = "Value",
    "fr" = "Valeur",
    "de" = "Wert",
    "it" = "Valore",
    "es" = "Valor"
  )

tbl_lab_count <- 
  c(
    "en" = "Count",
    "fr" = "Compte",
    "de" = "Z\u00E4hlung",
    "it" = "Conteggio",
    "es" = "Cuenta"
  )

tbl_lab_frequency <- 
  c(
    "en" = "Frequency",
    "fr" = "Fr\u00E9quence",
    "de" = "Frequenz",
    "it" = "Frequenza",
    "es" = "Frecuencia"
  )

plot_lab_count <- tbl_lab_count

plot_lab_string_length <- 
  c(
    "en" = "String Length",
    "fr" = "Longueur de cha\u00EEne de caract\u00E8res",
    "de" = "String-L\u00E4nge",
    "it" = "Lunghezza della stringa",
    "es" = "Longitud de la cadena de caracteres"
  )

other_values_text <-
  c(
    "en" = "Other Values",
    "fr" = "Autres valeurs",
    "de" = "Andere Werte",
    "it" = "Altri valori",
    "es" = "Otros valores"
  )

footer_text_fragment <-
  c(
    "en" = "Table scan generated with <a href=\"https://www.github.com/rich-iannone/pointblank\">pointblank</a>.",
    "fr" = "Scan de table g\u00E9n\u00E9r\u00E9 avec <a href=\"https://www.github.com/rich-iannone/pointblank\">pointblank</a>.",
    "de" = "Mit <a href=\"https://www.github.com/rich-iannone/pointblank\">pointblank</a> generierter Tabellenscan.",
    "it" = "Scansione della tabella generata con <a href=\"https://www.github.com/rich-iannone/pointblank\">pointblank</a>.",
    "es" = "Escaneo de Tabla generado con <a href=\"https://www.github.com/rich-iannone/pointblank\">pointblank</a>."
  )

==> pointblank_0.5.2.tar.gz: pointblank/R/utils_text_table_scan.R <==
#
# Text for table scan (ts) report
#

nav_title_ts <- 
  c(
    "en" = "Table Scan",
    "fr" = "Scan de table",
    "de" = "Scan der Tabelle",
    "it" = "Scansione della tabella",
    "es" = "Escaneo de Tabla"
  )

nav_overview_ts <- 
  c(
    "en" = "Overview",
    "fr" = "Aper\u00E7u",
    "de" = "\u00DCbersicht",
    "it" = "Panoramica",
    "es" = "Resumen"
  )

nav_variables_ts <- 
  c(
    "en" = "Variables",
    "fr" = "Variables",
    "de" = "Variablen",
    "it" = "Variabili",
    "es" = "Variables"
  )

nav_interactions_ts <- 
  c(
    "en" = "Interactions",
    "fr" = "Interactions",
    "de" = "Interaktionen",
    "it" = "Interazioni",
    "es" = "Interacciones"
  )

nav_correlations_ts <- 
  c(
    "en" = "Correlations",
    "fr" = "Corr\u00E9lations",
    "de" = "Korrelationen",
    "it" = "Correlazioni",
    "es" = "Correlaciones"
  )

nav_missing_values_ts <- 
  c(
    "en" = "Missing Values",
    "fr" = "Valeurs manquantes",
    "de" = "Fehlende Werte",
    "it" = "Valori mancanti",
    "es" = "Valores faltantes"
  )

nav_sample_values_ts <- 
  c(
    "en" = "Sample",
    "fr" = "Exemple",
    "de" = "Stichprobe",
    "it" = "Campione",
    "es" = "Muestra"
  )

section_title_overview_of_ts <- 
  c(
    "en" = "Overview of <code>{tbl_name}</code>",
    "fr" = "Aper\u00E7u du tableau <code>{tbl_name}</code>",
    "de" = "\u00DCbersicht \u00FCber die Tabelle <code>{tbl_name}</code>",
    "it" = "Panoramica della tabella <code>{tbl_name}</code>",
    "es" = "Resumen de la tabla <code>{tbl_name}</code>"
  )

section_title_overview_ts <- nav_overview_ts
section_title_variables_ts <- nav_variables_ts
section_title_interactions_ts <- nav_interactions_ts
section_title_correlations_ts <- nav_correlations_ts
section_title_missing_values_ts <- nav_missing_values_ts
section_title_sample_values_ts <- nav_sample_values_ts


button_label_overview_overview_ts <- nav_overview_ts

button_label_overview_reproducibility_ts <-
  c(
    "en" = "Reproducibility",
    "fr" = "Reproductibilit\u00E9",
    "de" = "Reproduzierbarkeit",
    "it" = "Riproducibilit\u00E0",
    "es" = "Reproducibilidad"
  )

tab_label_variables_statistics_ts <-
  c(
    "en" = "Statistics",
    "fr" = "Statistiques",
    "de" = "Statistiken",
    "it" = "Statistica",
    "es" = "Estad\u00EDsticas"
  )

tab_label_variables_common_values_ts <-
  c(
    "en" = "Common Values",
    "fr" = "Valeurs communes",
    "de" = "H\u00E9ufigste Werte",
    "it" = "Valori comuni",
    "es" = "Valores comunes"
  )

tab_label_variables_max_min_slices_ts <-
  c(
    "en" = "Max/Min Slices",
    "fr" = "Tranche sup\u00E9rieure et inf\u00E9rieure",
    "de" = "Minimale und maximale Werte",
    "it" = "Fetta superiore e inferiore",
    "es" = "Rebanada superior e inferior"
  )

subsection_title_overview_table_overview <-
  c(
    "en" = "Table Overview",
    "fr" = "Aper\u00E7u du tableau",
    "de" = "\u00DCbersicht der Tabelle",
    "it" = "Panoramica della tabella",
    "es" = "Resumen de la tabla"
  )

subsection_title_overview_column_types <-
  c(
    "en" = "Column Types",
    "fr" = "Types de colonnes",
    "de" = "Spaltentypen",
    "it" = "Tipi di colonna",
    "es" = "Tipos de columna"
  )

subsection_title_overview_reproducibility_information <-
  c(
    "en" = "Reproducibility Information",
    "fr" = "Informations sur la reproductibilit\u00E9",
    "de" = "Informationen zur Reproduzierbarkeit",
    "it" = "Informazioni sulla riproducibilit\u00E0",
    "es" = "Informaci\u00F3n de reproducibilidad"
  )

subsection_title_variables_quantile_statistics <-
  c(
    "en" = "Quantile Statistics",
    "fr" = "Statistiques quantiles",
    "de" = "Verteilungswerte",
    "it" = "Statistiche quantili",
    "es" = "Estad\u00EDsticas cuantiles"
  )

subsection_title_variables_descriptive_statistics <-
  c(
    "en" = "Descriptive Statistics",
    "fr" = "Statistiques descriptives",
    "de" = "Deskriptive Statistik",
    "it" = "Statistiche descrittive",
    "es" = "Estad\u00EDsticas descriptivas"
  )

subsection_title_variables_common_values <- tab_label_variables_common_values_ts

subsection_title_variables_maximum_values <-
  c(
    "en" = "Maximum Values",
    "fr" = "Valeurs maximales",
    "de" = "Maximalwerte",
    "it" = "Valori massimi",
    "es" = "Valores m\u00E1ximos"
  )

subsection_title_variables_minimum_values <-
  c(
    "en" = "Minimum Values",
    "fr" = "Valeurs minimales",
    "de" = "Minimalwerte",
    "it" = "Valori minimi",
    "es" = "Valores m\u00EDnimos"
  )

subsection_title_variables_string_lengths <-
  c(
    "en" = "String Lengths",
    "fr" = "Longueurs de cha\u00EEne de caract\u00E8res",
    "de" = "Zeichenl\u00E4ngen",
    "it" = "Lunghezza delle stringhe",
    "es" = "Longitudes de la cadena de caracteres"
  )

subsection_title_variables_histogram <-
  c(
    "en" = "Histogram",
    "fr" = "Histogramme",
    "de" = "Histogramm",
    "it" = "Istogramma",
    "es" = "Histograma"
  )

btn_toggle_details <- 
  c(
    "en" = "Toggle details",
    "fr" = "Basculer les d\u00E9tails",
    "de" = "Details einblenden",
    "it" = "Attiva / disattiva i dettagli",
    "es" = "Alternar detalles"
  )

tbl_lab_columns <- 
  c(
    "en" = "Columns",
    "fr" = "Colonnes",
    "de" = "Spalten",
    "it" = "Colonne",
    "es" = "Columnas"
  )

tbl_lab_rows <- 
  c(
    "en" = "Rows",
    "fr" = "Enregistrements",
    "de" = "Eintr\u00E4ge",
    "it" = "Record",
    "es" = "Registros"
  )

tbl_lab_NAs <- 
  c(
    "en" = "`NA`s",
    "fr" = "Valeurs `NA`",
    "de" = "`NA`-Werte",
    "it" = "Valori `NA`",
    "es" = "Valores de `NA`"
  )

tbl_lab_duplicate_rows <- 
  c(
    "en" = "Duplicate Rows",
    "fr" = "Enregistrements en double",
    "de" = "Doppelte Eintr\u00E4ge",
    "it" = "Record duplicati",
    "es" = "Registros duplicados"
  )

tbl_lab_scan_build_time <- 
  c(
    "en" = "Scan Build Time",
    "fr" = "Moment de l'analyse",
    "de" = "Zeitpunkt des Scans",
    "it" = "Tempo di scansione",
    "es" = "Tiempo de escaneo"
  )

tbl_lab_pointblank_version <- 
  c(
    "en" = "**pointblank** Version",
    "fr" = "version **pointblank**",
    "de" = "**pointblank** Version",
    "it" = "versione **pointblank**",
    "es" = "Versi\u00F3n **pointblank**"
  )

tbl_lab_r_version <- 
  c(
    "en" = "**R** Version",
    "fr" = "version **R**",
    "de" = "**R** Version",
    "it" = "versione **R**",
    "es" = "Versi\u00F3n **R**"
  )

tbl_lab_system_os <- 
  c(
    "en" = "Operating System",
    "fr" = "Syst\u00E8me op\u00E9rateur",
    "de" = "Betriebssystem",
    "it" = "Sistema operativo",
    "es" = "Sistema operativo"
  )

tbl_lab_distinct <- 
  c(
    "en" = "Distinct",
    "fr" = "valeurs uniques",
    "de" = "Einzigartige Werte",
    "it" = "Valori unici",
    "es" = "Valores \u00FAnicos"
  )

tbl_lab_mean <- 
  c(
    "en" = "Mean",
    "fr" = "Moyenne",
    "de" = "Mittelwert",
    "it" = "Media",
    "es" = "Media"
  )

tbl_lab_minimum <- 
  c(
    "en" = "Minimum",
    "fr" = "Minimum",
    "de" = "Minimum",
    "it" = "Minimo",
    "es" = "M\u00EDnimo"
  )

tbl_lab_maximum <- 
  c(
    "en" = "Maximum",
    "fr" = "Maximum",
    "de" = "Maximum",
    "it" = "Massimo",
    "es" = "M\u00E1ximo"
  )

tbl_lab_5_percentile <- 
  c(
    "en" = "5th Percentile",
    "fr" = "5e centile",
    "de" = "5tes Perzentil",
    "it" = "5 percentile",
    "es" = "Quinto percentil"
  )

tbl_lab_median <- 
  c(
    "en" = "Median",
    "fr" = "M\u00E9diane",
    "de" = "Median",
    "it" = "Mediana",
    "es" = "Mediana"
  )

tbl_lab_95_percentile <- 
  c(
    "en" = "95th Percentile",
    "fr" = "95e centile",
    "de" = "95tes Perzentil",
    "it" = "95 percentile",
    "es" = "Percentil 95"
  )

tbl_lab_range <- 
  c(
    "en" = "Range",
    "fr" = "\u00C9tendue",
    "de" = "Spannweite",
    "it" = "Campo di variazione",
    "es" = "Rango"
  )

tbl_lab_variance <- 
  c(
    "en" = "Variance",
    "fr" = "Variance",
    "de" = "Varianz",
    "it" = "Varianza",
    "es" = "Varianza"
  )

tbl_lab_standard_deviation <- 
  c(
    "en" = "Standard Deviation",
    "fr" = "\u00C9cart type",
    "de" = "Standardabweichung",
    "it" = "Deviazione standard",
    "es" = "Desviaci\u00F3n Est\u00E1ndar"
  )

tbl_lab_cov <- 
  c(
    "en" = "Coefficient of Variation",
    "fr" = "Coefficient de variation",
    "de" = "Variationskoeffizient",
    "it" = "Coefficiente di variazione",
    "es" = "Coeficiente de variaci\u00F3n"
  )

tbl_lab_value <- 
  c(
    "en" = "Value",
    "fr" = "Valeur",
    "de" = "Wert",
    "it" = "Valore",
    "es" = "Valor"
  )

tbl_lab_count <- 
  c(
    "en" = "Count",
    "fr" = "Compte",
    "de" = "Anzahl",
    "it" = "Conteggio",
    "es" = "Cuenta"
  )

tbl_lab_frequency <- 
  c(
    "en" = "Frequency",
    "fr" = "Fr\u00E9quence",
    "de" = "Frequenz",
    "it" = "Frequenza",
    "es" = "Frecuencia"
  )

plot_lab_count <- tbl_lab_count

plot_lab_string_length <- 
  c(
    "en" = "String Length",
    "fr" = "Longueur de cha\u00EEne de caract\u00E8res",
    "de" = "Zeichenl\u00E4nge",
    "it" = "Lunghezza della stringa",
    "es" = "Longitud de la cadena de caracteres"
  )

other_values_text <-
  c(
    "en" = "Other Values",
    "fr" = "Autres valeurs",
    "de" = "Andere Werte",
    "it" = "Altri valori",
    "es" = "Otros valores"
  )

footer_text_fragment <-
  c(
    "en" = "Table scan generated with <a href=\"https://www.github.com/rich-iannone/pointblank\">pointblank</a>.",
    "fr" = "Scan de table g\u00E9n\u00E9r\u00E9 avec <a href=\"https://www.github.com/rich-iannone/pointblank\">pointblank</a>.",
    "de" = "Mit <a href=\"https://www.github.com/rich-iannone/pointblank\">pointblank</a> generierter Scan der Tabelle",
    "it" = "Scansione della tabella generata con <a href=\"https://www.github.com/rich-iannone/pointblank\">pointblank</a>.",
    "es" = "Escaneo de Tabla generado con <a href=\"https://www.github.com/rich-iannone/pointblank\">pointblank</a>."
  )
